@@ -13,11 +13,13 @@ import json
 
 logging.basicConfig(level=logging.DEBUG)
 
-msgs = fedora_nightlies.datagrepper_query(['org.fedoraproject.prod.pungi.compose.status.change'], 180)
-urls = [msg.get('location') for msg in msgs]
+msgs = fedora_nightlies.datagrepper_query(
+    ["org.fedoraproject.prod.pungi.compose.status.change"], 180
+)
+urls = [msg.get("location") for msg in msgs]
 urls = set([url for url in urls if url])
 
-fn = 'compose-urls-{0}.json'.format(datetime.date.today().strftime('%Y%m%d'))
-fh = open(fn, 'w')
-json.dump(list(urls), fh, indent=4, separators=(',', ': '))
+fn = "compose-urls-{0}.json".format(datetime.date.today().strftime("%Y%m%d"))
+fh = open(fn, "w")
+json.dump(list(urls), fh, indent=4, separators=(",", ": "))
 fh.close()
